@@ -142,13 +142,13 @@ def _set_int_config_parameter(value: OZWValue, new_value: int) -> int:
     """Set a ValueType.INT config parameter."""
     try:
         new_value = int(new_value)
-    except ValueError:
+    except ValueError as err:
         raise WrongTypeError(
             (
                 f"Configuration parameter type {value.type} does not match "
                 f"the value type {type(new_value)}"
             )
-        )
+        ) from err
 
     if (value.max is not None and new_value > value.max) or (
         value.min is not None and new_value < value.min
@@ -221,7 +221,7 @@ def get_config_parameters(
         value_to_return = {
             ATTR_LABEL: value.label,
             ATTR_TYPE: value.type.value,
-            ATTR_PARAMETER: value.index.value,
+            ATTR_PARAMETER: value.index,
             ATTR_HELP: value.help,
         }
 
